@@ -7,7 +7,7 @@ from collections import	Counter
 #from so imoprt *
 eshost	= os.getenv("eshost", "127.0.0.1") 
 esport	= int(os.getenv("esport", 9200))
-requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
+#requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
 
 config = {  
 		"settings" : {
@@ -204,7 +204,7 @@ sntnum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'snt'" )[0]
 lexnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where low = '{w}' and type = 'tok'")[0][0] # opened = 70
 lemnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where lem = '{w}' and type = 'tok'")[0][0] 
 sqlsi	= lambda query: (si:=Counter(), [si.update({row[0]:1}) for row in sql(query)])[0]
-warmup  = lambda host, port: requests.put(f"http://{host}:{port}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
+warmup  = lambda : requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
 
 def readline(infile, sepa=None):
 	with open(infile, 'r') as fp:
